@@ -662,7 +662,7 @@ class Worker(Process):
 
         set_current_job(job)
 
-        extra = {"mrq_job_id": job.id, "params": job.data['params']}
+        extra = {"mrq_job_id": str(job.id), "data": job.data}
 
         try:
             job.perform()
